@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -367,6 +367,7 @@ gst_dvd_sub_dec_parse_subpic (GstDvdSubDec * dec)
                 gst_guint64_to_gdouble (GST_SECOND));
             return;
           }
+          break;
         } else {
           dec->parse_pos = NULL;
           dec->next_event_ts = GST_CLOCK_TIME_NONE;
