@@ -23,21 +23,21 @@
 
 /**
  * SECTION:element-xingmux
- * @title: xingmux
  *
  * xingmux adds a Xing header to MP3 files. This contains information about the duration and size
  * of the file and a seek table and is very useful for getting an almost correct duration and better
  * seeking on VBR MP3 files.
- *
+ * 
  * This element will remove any existing Xing, LAME or VBRI headers from the beginning of the file.
  *
- * ## Example launch line
+ * <refsect2>
+ * <title>Example launch line</title>
  * |[
- * gst-launch-1.0 audiotestsrc num-buffers=1000 ! audioconvert ! lamemp3enc ! xingmux ! filesink location=test.mp3
- * gst-launch-1.0 filesrc location=test.mp3 ! xingmux ! filesink location=test2.mp3
- * gst-launch-1.0 filesrc location=test.mp3 ! mp3parse ! xingmux ! filesink location=test2.mp3
+ * gst-launch audiotestsrc num-buffers=1000 ! audioconvert ! lamemp3enc ! xingmux ! filesink location=test.mp3
+ * gst-launch filesrc location=test.mp3 ! xingmux ! filesink location=test2.mp3
+ * gst-launch filesrc location=test.mp3 ! mp3parse ! xingmux ! filesink location=test2.mp3
  * ]|
- *
+ * </refsect2>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -275,10 +275,7 @@ generate_xing_header (GstXingMux * xing)
     header &= 0xffff0fff;
     header |= bitrate << 12;
 
-    if (!parse_header (header, &size, &spf, &rate)) {
-      GST_ERROR ("Failed to parse header!");
-      return NULL;
-    }
+    parse_header (header, &size, &spf, &rate);
     xing_offset = get_xing_offset (header);
   } while (size < (4 + xing_offset + 4 + 4 + 4 + 4 + 100) && bitrate < 0xe);
 
@@ -413,10 +410,10 @@ gst_xing_mux_class_init (GstXingMuxClass * klass)
   gstelement_class->change_state =
       GST_DEBUG_FUNCPTR (gst_xing_mux_change_state);
 
-  gst_element_class_add_static_pad_template (gstelement_class,
-      &gst_xing_mux_src_template);
-  gst_element_class_add_static_pad_template (gstelement_class,
-      &gst_xing_mux_sink_template);
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&gst_xing_mux_src_template));
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&gst_xing_mux_sink_template));
 
   GST_DEBUG_CATEGORY_INIT (xing_mux_debug, "xingmux", 0, "Xing Header Muxer");
 
